@@ -8,8 +8,8 @@
 
 int main(int argc, char  * argv[])
 {
-	Player app(argc, argv);
-	app.setApplicationName("necroplayer");
+    Player app(argc, argv);
+    app.setApplicationName("NecroPlayer2");
 
-	return app.exec();
+    return app.exec();
 }
